@@ -1,4 +1,4 @@
-import Control.Applicative
+{-# LANGUAGE DeriveFoldable #-}
 import Data.Unfoldable
 import Data.Unfolder
 
@@ -6,7 +6,7 @@ import Data.Maybe
 import System.Random
 
 
-data TB a = LB a | BB (TB (a, a)) deriving Show
+data TB a = LB a | BB (TB (a, a)) deriving (Show, Foldable)
 
 instance Unfoldable TB where
   unfold fa = choose
